@@ -3,7 +3,7 @@
 ##                                                                            ##
 ##  This file is part of NCrystal (see https://mctools.github.io/ncrystal/)   ##
 ##                                                                            ##
-##  Copyright 2015-2025 NCrystal developers                                   ##
+##  Copyright 2015-2026 NCrystal developers                                   ##
 ##                                                                            ##
 ##  Licensed under the Apache License, Version 2.0 (the "License");           ##
 ##  you may not use this file except in compliance with the License.          ##
@@ -912,9 +912,17 @@ class NCMATComposerImpl:
                                self.create_ncmat( cfg_params = cfg_params ) )
         return p
 
-    def load(self,cfg_params,force ):
-        if force or self.__loadcache is None or self.__loadcache[0] != cfg_params:
-            self.__loadcache = ( cfg_params, _nc_core.directLoad( self.create_ncmat(), cfg_params ) )
+    def load( self, cfg_params, force,
+              doInfo = True, doScatter = True, doAbsorption = True ):
+        key = ( cfg_params, doInfo, doScatter, doAbsorption )
+        if force or self.__loadcache is None or self.__loadcache[0] != key:
+            self.__loadcache = ( key,
+                                 _nc_core.directLoad( self.create_ncmat(),
+                                                      cfg_params = cfg_params,
+                                                      dtype = 'ncmat',
+                                                      doInfo = doInfo,
+                                                      doScatter = doScatter,
+                                                      doAbsorption = doAbsorption) )
         return self.__loadcache[1]
 
     def plot_xsect( self, composer, cfg_params, kwargs_plot_xsect ):
@@ -1834,7 +1842,18 @@ def _import_spglib( *, sysexit = False ):
             raise SystemExit(m)
         else:
             raise ImportError(m)
-    return spglib.spglib
+    if hasattr(spglib,'spglib'):
+        #spglib version < 2.7
+        return spglib.spglib
+    if hasattr(spglib,'OLD_ERROR_HANDLING'):
+        #For version 2.7 (and likely not later), we can avoid a deprecation
+        #warning by this trick:
+        try:
+            import spglib.error
+            spglib.error.OLD_ERROR_HANDLING = False
+        except (ImportError,AttributeError):
+            pass
+    return spglib
 
 def _import_ase( *, sysexit = False ):
     try:
